;; Generated package description from devdocs.el  -*- no-byte-compile: t -*-
(define-package "devdocs" "0.7" "Emacs viewer for DevDocs" '((emacs "27.1") (compat "30.1")) :commit "25c746024ddf73570195bf42b841f761a2fee10c" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("help") :url "https://github.com/astoff/devdocs.el")
